@@ -2,7 +2,7 @@
  * @file cmd.c
  * @brief R}hs֘A
  * @author BananaJinn
- * @version $Id: cmd.c,v 1.18 2006/03/21 14:06:22 bananajinn Exp $
+ * @version $Id: cmd.c,v 1.20 2008/01/04 14:09:58 bananajinn Exp $
  * ~Օʉ
  * Copyright (C) 2004-2006 BananaJinn<banana@mxh.mesh.ne.jp>.
  */
@@ -54,6 +54,42 @@ void Set4bytes(BYTE *buf, DWORD value)
 	buf[3] = (BYTE)value;
 }
 
+WORD Get2bytesLE(BYTE *buf)
+{
+	return (WORD)buf[1]<<8 | buf[0];
+}
+
+DWORD Get3bytesLE(BYTE *buf)
+{
+	return (DWORD)buf[2]<<16 | (DWORD)buf[1]<<8 | buf[0];
+}
+
+DWORD Get4bytesLE(BYTE *buf)
+{
+	return (DWORD)buf[3]<<24 | (DWORD)buf[2]<<16 | (DWORD)buf[1]<<8 | buf[0];
+}
+
+void Set2bytesLE(BYTE *buf, WORD value)
+{
+	buf[1] = (BYTE)(value>>8);
+	buf[0] = (BYTE)value;
+}
+
+void Set3bytesLE(BYTE *buf, DWORD value)
+{
+	buf[2] = (BYTE)(value>>16);
+	buf[1] = (BYTE)(value>>8);
+	buf[0] = (BYTE)value;
+}
+
+void Set4bytesLE(BYTE *buf, DWORD value)
+{
+	buf[3] = (BYTE)(value>>24);
+	buf[2] = (BYTE)(value>>16);
+	buf[1] = (BYTE)(value>>8);
+	buf[0] = (BYTE)value;
+}
+
 
 DWORD MSF2LBA(BYTE min, BYTE sec, BYTE frame, BOOL force_positive)
 {
@@ -451,6 +487,17 @@ int OpenTray(CMDDRIVE *drive)
 	return RET_OK;
   }
   
+  SendPreventAllow(drive, 0);
+  return SendStartStop(drive, 0, 1, 0);
+}
+
+int OpenTrayImmediate(CMDDRIVE *drive)
+{
+  if(drive->type == CMDDRVTYPE_NET){
+		/* lbg[N摕ũgC͍sȂ */
+	return RET_OK;
+  }
+  
   SendPreventAllow(drive, 0);
   return SendStartStop(drive, 1, 1, 0);
 }
@@ -461,7 +508,7 @@ int CloseTray(CMDDRIVE *drive)
 		/* lbg[N摕ũgC͍sȂ */
 	return RET_OK;
   }
-  return SendStartStop(drive, 1, 1, 1);
+  return SendStartStop(drive, 0, 1, 1);
 }
 
 
@@ -546,7 +593,7 @@ int CheckReady(CMDDRIVE *drive, BOOL bWaitDisc)
 		  if(bWaitDisc){
 				/* Eject */
 			if(bEjected==FALSE){
-			  OpenTray(drive);
+			  OpenTrayImmediate(drive);
 			  bEjected=TRUE;
 			  UIDispInfo(MSG_INSERT_DISC /*"fBXN}Ă"*/);
 			}
