@@ -2,7 +2,7 @@
  * @file copydisc.c
  * @brief ~Ղ𕡎
  * @author BananaJinn
- * @version $Id: copydisc.c,v 1.61 2007/10/02 15:10:52 bananajinn Exp $
+ * @version $Id: copydisc.c,v 1.65 2008/11/07 13:23:16 bananajinn Exp $
  * ~Օʉ
  * Copyright (C) 2004-2006 BananaJinn<banana@mxh.mesh.ne.jp>.
  */
@@ -1444,12 +1444,15 @@ static int CopyTrack(CMDDRIVE *src, CMDDRIVE *dst, int num_dst,
  * @param[in]	discinfo  fBXN
  * @param[in]	track_start JngbNԍ
  * @param[out]	cs_ret	쐬CueSheet
+ * @param[out]  numcs_ret 쐬CueSheetz̗vf
+ * @param[in]   enable_cdtext CD-TEXTLɂ邩ǂ
  * @retval	RET_OK	I
  * @retval	RET_NG	G[
  */
 static int CreateCueSheet(CMDDRIVE *drive, CPDISCINFO *discinfo,
 						  WORD track_start,
-						  struct _CUESHEET **cs_ret)
+						  struct _CUESHEET **cs_ret, int *numcs_ret,
+						  BOOL enable_cdtext)
 {
 	struct _CUESHEET *cs = NULL, *csp;
 	int cur_cs = 0;
@@ -1462,262 +1465,256 @@ static int CreateCueSheet(CMDDRIVE *drive, CPDISCINFO *discinfo,
 	int ret;
 	BOOL gap_2part;
 	BOOL cdtext=FALSE;
-	int retry;	/* CD-TEXTT|[ghCüׂ̃gC */
 	WORD track_num;
 
-	if(track_start==1 && discinfo->cdtext_size>0)
+	if(track_start==1 && discinfo->cdtext_size>0 && enable_cdtext)
 		cdtext = TRUE;
 
-	for(retry=0; retry<2; retry++){
-		track_num = track_start;
-		cur_cs = 0;
-		num_cs = 0;
-		sess_num = 0;
-		/* NWA擾 */
-		if(!REALDRIVE(drive)){
-			nwa = -150;
+	track_num = track_start;
+	cur_cs = 0;
+	num_cs = 0;
+	sess_num = 0;
+	/* NWA擾 */
+	if(!REALDRIVE(drive)){
+		nwa = -150;
+	}
+	else{
+		ret = SendReadTrackInfo(drive, track_num);
+		if(ret!=RET_OK){
+			DispCommandError(drive);
+			return ret;
 		}
-		else{
-			ret = SendReadTrackInfo(drive, track_num);
-			if(ret!=RET_OK){
-				DispCommandError(drive);
-				return ret;
-			}
-			ti = (struct _TRACKINFO *)drive->data_buf;
-			nwa = Get4bytes(ti->next_writable_addr);
-			if(nwa == (DWORD)0){
-			  nwa -= 150;
-			}
+		ti = (struct _TRACKINFO *)drive->data_buf;
+		nwa = Get4bytes(ti->next_writable_addr);
+		if(nwa == (DWORD)0){
+			nwa -= 150;
 		}
+	}
 
-		if(strlen((char *)discinfo->media_catalog_number)!=0){
-			/* Media Catalog Number */
-			DebugLog("CreateCueSheet: Media catalog number.\n");
-			num_cs += 2;
-			cs = (struct _CUESHEET *)MemResize(cs, num_cs * sizeof(struct _CUESHEET));
-			if(cs==NULL)
-				return RET_MEMERR;
-			csp = &cs[cur_cs++];
-			csp->ctladr = CSADR_MCN;
-			memcpy(&csp->tno, discinfo->media_catalog_number, 7);
-			csp = &cs[cur_cs++];
-			csp->ctladr = CSADR_MCN;
-			memcpy(&csp->tno, discinfo->media_catalog_number+7, 7);
-		}
-
-		cpti = NULL;
-		lcpti = NULL;
-		ret = RET_OK;
-		for( ; track_num <= discinfo->tracks; track_num++){
-			lcpti = cpti;
-			cpti = &discinfo->trackinfo[track_num-1];
-			gap_len = 0;
-			if(sess_num==0){
-				DebugLog("CreateCueSheet: Lead-in.\n");
-				sess_num = (WORD)cpti->trackinfo.session_number_msb<<8 |
-					(WORD)cpti->trackinfo.session_number_lsb;
-				/* Lead-in */
-				num_cs++;
-				cs = (struct _CUESHEET *)MemResize(cs, num_cs * sizeof(struct _CUESHEET));
-				if(cs==NULL)
-					return RET_MEMERR;
-				csp = &cs[cur_cs++];
-				csp->ctladr = IS_TRACKMODE_DATA(cpti->trackinfo.track_mode) ? CSCTL_DATA : CSCTL_AUDIO;
-				csp->ctladr |= CSADR_NORMAL;
-				csp->tno = 0;
-				csp->index = 0;
-				csp->dataform = cdtext ? 0x41 : 0x01;
-				csp->scms = 0;
-				LBA2MSF(nwa, &csp->min, &csp->sec, &csp->frame);
-				gap_len = Get4bytes(cpti->trackinfo.track_start) - nwa;
-			}
-			else if(sess_num != ((WORD)cpti->trackinfo.session_number_msb<<8 |
-								 (WORD)cpti->trackinfo.session_number_lsb)){
-				cpti = lcpti;
-				break;
-			}
-
-			if(strlen((char *)cpti->isrc)!=0){
-				/* ISRC */
-				DebugLog("CreateCueSheet: ISRC.\n");
-				num_cs += 2;
-				cs = (struct _CUESHEET *)MemResize(cs, num_cs * sizeof(struct _CUESHEET));
-				if(cs==NULL)
-					return RET_MEMERR;
-				csp = &cs[cur_cs++];
-				csp->ctladr = CSADR_ISRC;
-				csp->tno = (BYTE)track_num;
-				memcpy(&csp->index, cpti->isrc, 6);
-				csp = &cs[cur_cs++];
-				csp->ctladr = CSADR_ISRC;
-				csp->tno = (BYTE)track_num;
-				memcpy(&csp->index, cpti->isrc+6, 6);
-			}
-			gap_2part = FALSE;
-			if(gap_len==0){
-#if 1	/* ̕ǂ? */
-				if(lcpti!=NULL){
-					gap_len = Get4bytes(cpti->trackinfo.track_start) -
-						(Get4bytes(lcpti->trackinfo.track_start) +
-						 Get4bytes(lcpti->trackinfo.track_size));
-					if(IS_TRACKMODE_DATA(cpti->trackinfo.track_mode)){
-						/* DATA */
-						if(!IS_TRACKMODE_DATA(lcpti->trackinfo.track_mode) ||
-						   lcpti->mode2 != cpti->mode2){
-							/* 2part */
-							DebugLog("CreateCueSheet: Two part pregap.(cdda -> data)\n");
-							gap_2part = TRUE;
-						}
-					}
-					else{
-						/* AUDIO */
-						if(IS_TRACKMODE_DATA(lcpti->trackinfo.track_mode)){
-							/* ODATȀꍇ? */
-							DebugLog("CreateCueSheet: Two part pregap.(data -> cdda)\n");
-							gap_2part = TRUE;
-						}
-					}
-				}
-#else
-				if(!IS_TRACKMODE_DATA(cpti->trackinfo.track_mode)){
-					/* AUDIO */
-					gap_len = cpti->pause_len;
-				}
-				else if(lcpti!=NULL){
-					/* DATA  2nd ȍ~ */
-					gap_len = 150;
-					if(!IS_TRACKMODE_DATA(lcpti->trackinfo.track_mode) ||
-					   lcpti->mode2 != cpti->mode2){
-						/* 2part */
-						gap_len = 75+150;
-						gap_2part = TRUE;
-					}
-				}
-#endif
-			}
-			nwa = Get4bytes(cpti->trackinfo.track_start) - gap_len;
-			DebugLog("CreateCueSheet: track=%d gap=%ld nwa=0x%08lX\n",
-					 track_num, gap_len, nwa);
-			if(gap_len>0){
-				/* pre-gap */
-				if(gap_2part && gap_len>150){
-					num_cs++;
-					cs = (struct _CUESHEET *)MemResize(cs, num_cs * sizeof(struct _CUESHEET));
-					if(cs==NULL)
-						return RET_MEMERR;
-					csp = &cs[cur_cs++];
-					csp->ctladr = IS_TRACKMODE_DATA(lcpti->trackinfo.track_mode) ? CSCTL_DATA : CSCTL_AUDIO;
-					csp->ctladr |= CSADR_NORMAL;
-					csp->tno = (BYTE)track_num;
-					csp->index = 0;
-#if SEND_GAPDATA
-					if(!IS_TRACKMODE_DATA(lcpti->trackinfo.track_mode)){
-						csp->dataform = 0x00;
-					}
-					else{
-						csp->dataform = lcpti->mode2 ? 0x20 : 0x10;
-					}
-#else
-					if(!IS_TRACKMODE_DATA(lcpti->trackinfo.track_mode)){
-						csp->dataform = 0x01;
-					}
-					else{
-						csp->dataform = lcpti->mode2 ? 0x24 : 0x14;
-					}
-#endif
-					csp->scms = lcpti->trackinfo.copy ? 0x80 : 0;
-					LBA2MSF(nwa, &csp->min, &csp->sec, &csp->frame);
-					nwa += (gap_len-150);
-					gap_len = 150;
-					DebugLog("CreateCueSheet: Pre-gap.\n");
-				}
-				num_cs++;
-				cs = (struct _CUESHEET *)MemResize(cs, num_cs * sizeof(struct _CUESHEET));
-				if(cs==NULL)
-					return RET_MEMERR;
-				csp = &cs[cur_cs++];
-				csp->ctladr = IS_TRACKMODE_DATA(cpti->trackinfo.track_mode) ? CSCTL_DATA : CSCTL_AUDIO;
-				csp->ctladr |= CSADR_NORMAL;
-				csp->tno = (BYTE)track_num;
-				csp->index = 0;
-#if SEND_GAPDATA
-				if(!IS_TRACKMODE_DATA(cpti->trackinfo.track_mode)){
-					csp->dataform = 0x00;
-				}
-				else{
-					csp->dataform = cpti->mode2 ? 0x20 : 0x10;
-				}
-#else
-				if(!IS_TRACKMODE_DATA(cpti->trackinfo.track_mode)){
-					csp->dataform = 0x01;
-				}
-				else{
-					csp->dataform = cpti->mode2 ? 0x24 : 0x14;
-				}
-#endif
-				csp->scms = cpti->trackinfo.copy ? 0x80 : 0;
-				LBA2MSF(nwa, &csp->min, &csp->sec, &csp->frame);
-	
-				nwa += gap_len;
-			}
-			/* Audio/Data */
-			num_cs++;
-			cs = (struct _CUESHEET *)MemResize(cs, num_cs * sizeof(struct _CUESHEET));
-			if(cs==NULL)
-				return RET_MEMERR;
-			csp = &cs[cur_cs++];
-			csp->ctladr = IS_TRACKMODE_DATA(cpti->trackinfo.track_mode) ? CSCTL_DATA : CSCTL_AUDIO;
-			csp->ctladr |= CSADR_NORMAL;
-			csp->tno = (BYTE)track_num;
-			csp->index = 1;
-			if(!IS_TRACKMODE_DATA(cpti->trackinfo.track_mode))
-				csp->dataform = 0x00;
-			else
-				csp->dataform = cpti->mode2 ? 0x20 : 0x10;
-			csp->scms = cpti->trackinfo.copy ? 0x80 : 0;
-			LBA2MSF(nwa, &csp->min, &csp->sec, &csp->frame);
-			nwa += Get4bytes(cpti->trackinfo.track_size);
-			DebugLog("CreateCueSheet: Track%d.\n", track_num);
-		}
-		/* Lead-out */
-		num_cs++;
+	if(strlen((char *)discinfo->media_catalog_number)!=0){
+		/* Media Catalog Number */
+		DebugLog("CreateCueSheet: Media catalog number.\n");
+		num_cs += 2;
 		cs = (struct _CUESHEET *)MemResize(cs, num_cs * sizeof(struct _CUESHEET));
 		if(cs==NULL)
 			return RET_MEMERR;
 		csp = &cs[cur_cs++];
-		csp->ctladr = IS_TRACKMODE_DATA(cpti->trackinfo.track_mode) ? CSCTL_DATA : CSCTL_AUDIO;
-		csp->ctladr |= CSADR_NORMAL;
-		csp->tno = 0xAA;
-		csp->index = 1;
-		if(!IS_TRACKMODE_DATA(cpti->trackinfo.track_mode))
-			csp->dataform = 0x01;
-		else
-			csp->dataform = cpti->mode2 ? 0x24 : 0x14;
-		csp->scms = cpti->trackinfo.copy ? 0x80 : 0;
-		LBA2MSF(nwa, &csp->min, &csp->sec, &csp->frame);
-		DebugLog("CreateCueSheet: Lead-out.\n", track_num);
+		csp->ctladr = CSADR_MCN;
+		memcpy(&csp->tno, discinfo->media_catalog_number, 7);
+		csp = &cs[cur_cs++];
+		csp->ctladr = CSADR_MCN;
+		memcpy(&csp->tno, discinfo->media_catalog_number+7, 7);
+	}
+	
+	cpti = NULL;
+	lcpti = NULL;
+	ret = RET_OK;
+	for( ; track_num <= discinfo->tracks; track_num++){
+		lcpti = cpti;
+		cpti = &discinfo->trackinfo[track_num-1];
+		gap_len = 0;
+		if(sess_num==0){
+			DebugLog("CreateCueSheet: Lead-in.\n");
+			sess_num = (WORD)cpti->trackinfo.session_number_msb<<8 |
+				(WORD)cpti->trackinfo.session_number_lsb;
+				/* Lead-in */
+			num_cs++;
+			cs = (struct _CUESHEET *)MemResize(
+				cs, num_cs * sizeof(struct _CUESHEET));
+			if(cs==NULL)
+				return RET_MEMERR;
+			csp = &cs[cur_cs++];
+			csp->ctladr = IS_TRACKMODE_DATA(cpti->trackinfo.track_mode)
+				? CSCTL_DATA : CSCTL_AUDIO;
+			csp->ctladr |= CSADR_NORMAL;
+			csp->tno = 0;
+			csp->index = 0;
+			csp->dataform = cdtext ? 0x41 : 0x01;
+			csp->scms = 0;
+			if(sess_num >= 2){
+				nwa -= 150;	/* pregap */
+			}
+			LBA2MSF(nwa, &csp->min, &csp->sec, &csp->frame);
+			gap_len = Get4bytes(cpti->trackinfo.track_start) - nwa;
+		}
+		else if(sess_num != ((WORD)cpti->trackinfo.session_number_msb<<8 |
+							 (WORD)cpti->trackinfo.session_number_lsb)){
+			cpti = lcpti;
+			break;
+		}
 
-		*cs_ret = cs;
-
-		if(REALDRIVE(drive)){
-			ret = SendSendCueSheet(drive, cs, num_cs*sizeof(struct _CUESHEET));
-			if(ret!=RET_OK){
-				if(!retry && cdtext){
-					cdtext = FALSE;	/* CD-TEXT 𖳌ɂăgC */
-					DebugLog("CreateCueSheet: Retry(CD-TEXT is ignored).\n");
+		if(strlen((char *)cpti->isrc)!=0){
+			/* ISRC */
+			DebugLog("CreateCueSheet: ISRC.\n");
+			num_cs += 2;
+			cs = (struct _CUESHEET *)MemResize(
+				cs, num_cs * sizeof(struct _CUESHEET));
+			if(cs==NULL)
+				return RET_MEMERR;
+			csp = &cs[cur_cs++];
+			csp->ctladr = CSADR_ISRC;
+			csp->tno = (BYTE)track_num;
+			memcpy(&csp->index, cpti->isrc, 6);
+			csp = &cs[cur_cs++];
+			csp->ctladr = CSADR_ISRC;
+			csp->tno = (BYTE)track_num;
+			memcpy(&csp->index, cpti->isrc+6, 6);
+		}
+		gap_2part = FALSE;
+		if(gap_len==0){
+#if 1	/* ̕ǂ? */
+			if(lcpti!=NULL){
+				gap_len = Get4bytes(cpti->trackinfo.track_start) -
+					(Get4bytes(lcpti->trackinfo.track_start) +
+					 Get4bytes(lcpti->trackinfo.track_size));
+				if(IS_TRACKMODE_DATA(cpti->trackinfo.track_mode)){
+					/* DATA */
+					if(!IS_TRACKMODE_DATA(lcpti->trackinfo.track_mode) ||
+					   lcpti->mode2 != cpti->mode2){
+						/* 2part */
+						DebugLog("CreateCueSheet: Two part pregap.(cdda -> data)\n");
+						gap_2part = TRUE;
+					}
 				}
 				else{
-					DispCommandError(drive);
-					*cs_ret = NULL;
-					MemFree(cs);
-					return ret;
+					/* AUDIO */
+					if(IS_TRACKMODE_DATA(lcpti->trackinfo.track_mode)){
+						/* ODATȀꍇ? */
+						DebugLog("CreateCueSheet: Two part pregap.(data -> cdda)\n");
+						gap_2part = TRUE;
+					}
 				}
 			}
+#else
+			if(!IS_TRACKMODE_DATA(cpti->trackinfo.track_mode)){
+				/* AUDIO */
+				gap_len = cpti->pause_len;
+			}
+			else if(lcpti!=NULL){
+				/* DATA  2nd ȍ~ */
+				gap_len = 150;
+				if(!IS_TRACKMODE_DATA(lcpti->trackinfo.track_mode) ||
+				   lcpti->mode2 != cpti->mode2){
+					/* 2part */
+					gap_len = 75+150;
+					gap_2part = TRUE;
+				}
+			}
+#endif
 		}
-		if(ret==RET_OK)
-			break;
+		nwa = Get4bytes(cpti->trackinfo.track_start) - gap_len;
+		DebugLog("CreateCueSheet: track=%d gap=%ld nwa=0x%08lX\n",
+				 track_num, gap_len, nwa);
+		if(gap_len>0){
+			/* pre-gap */
+			if(gap_2part && gap_len>150){
+				num_cs++;
+				cs = (struct _CUESHEET *)MemResize(
+					cs, num_cs * sizeof(struct _CUESHEET));
+				if(cs==NULL)
+					return RET_MEMERR;
+				csp = &cs[cur_cs++];
+				csp->ctladr =
+					IS_TRACKMODE_DATA(lcpti->trackinfo.track_mode)
+					? CSCTL_DATA : CSCTL_AUDIO;
+				csp->ctladr |= CSADR_NORMAL;
+				csp->tno = (BYTE)track_num;
+				csp->index = 0;
+#if SEND_GAPDATA
+				if(!IS_TRACKMODE_DATA(lcpti->trackinfo.track_mode)){
+					csp->dataform = 0x00;
+				}
+				else{
+					csp->dataform = lcpti->mode2 ? 0x20 : 0x10;
+				}
+#else
+				if(!IS_TRACKMODE_DATA(lcpti->trackinfo.track_mode)){
+					csp->dataform = 0x01;
+				}
+				else{
+					csp->dataform = lcpti->mode2 ? 0x24 : 0x14;
+				}
+#endif
+				csp->scms = lcpti->trackinfo.copy ? 0x80 : 0;
+				LBA2MSF(nwa, &csp->min, &csp->sec, &csp->frame);
+				nwa += (gap_len-150);
+				gap_len = 150;
+				DebugLog("CreateCueSheet: Pre-gap.\n");
+			}
+			num_cs++;
+			cs = (struct _CUESHEET *)MemResize(
+				cs, num_cs * sizeof(struct _CUESHEET));
+			if(cs==NULL)
+				return RET_MEMERR;
+			csp = &cs[cur_cs++];
+			csp->ctladr = IS_TRACKMODE_DATA(cpti->trackinfo.track_mode)
+				? CSCTL_DATA : CSCTL_AUDIO;
+			csp->ctladr |= CSADR_NORMAL;
+			csp->tno = (BYTE)track_num;
+			csp->index = 0;
+#if SEND_GAPDATA
+			if(!IS_TRACKMODE_DATA(cpti->trackinfo.track_mode)){
+				csp->dataform = 0x00;
+			}
+			else{
+				csp->dataform = cpti->mode2 ? 0x20 : 0x10;
+			}
+#else
+			if(!IS_TRACKMODE_DATA(cpti->trackinfo.track_mode)){
+				csp->dataform = 0x01;
+			}
+			else{
+				csp->dataform = cpti->mode2 ? 0x24 : 0x14;
+			}
+#endif
+			csp->scms = cpti->trackinfo.copy ? 0x80 : 0;
+			LBA2MSF(nwa, &csp->min, &csp->sec, &csp->frame);
+			
+			nwa += gap_len;
+		}
+		/* Audio/Data */
+		num_cs++;
+		cs = (struct _CUESHEET *)MemResize(
+			cs, num_cs * sizeof(struct _CUESHEET));
+		if(cs==NULL)
+			return RET_MEMERR;
+		csp = &cs[cur_cs++];
+		csp->ctladr = IS_TRACKMODE_DATA(cpti->trackinfo.track_mode)
+			? CSCTL_DATA : CSCTL_AUDIO;
+		csp->ctladr |= CSADR_NORMAL;
+		csp->tno = (BYTE)track_num;
+		csp->index = 1;
+		if(!IS_TRACKMODE_DATA(cpti->trackinfo.track_mode))
+			csp->dataform = 0x00;
+		else
+			csp->dataform = cpti->mode2 ? 0x20 : 0x10;
+		csp->scms = cpti->trackinfo.copy ? 0x80 : 0;
+		LBA2MSF(nwa, &csp->min, &csp->sec, &csp->frame);
+		nwa += Get4bytes(cpti->trackinfo.track_size);
+		DebugLog("CreateCueSheet: Track%d.\n", track_num);
 	}
-
+	/* Lead-out */
+	num_cs++;
+	cs = (struct _CUESHEET *)MemResize(
+		cs, num_cs * sizeof(struct _CUESHEET));
+	if(cs==NULL)
+		return RET_MEMERR;
+	csp = &cs[cur_cs++];
+	csp->ctladr = IS_TRACKMODE_DATA(cpti->trackinfo.track_mode)
+		? CSCTL_DATA : CSCTL_AUDIO;
+	csp->ctladr |= CSADR_NORMAL;
+	csp->tno = 0xAA;
+	csp->index = 1;
+	if(!IS_TRACKMODE_DATA(cpti->trackinfo.track_mode))
+		csp->dataform = 0x01;
+	else
+		csp->dataform = cpti->mode2 ? 0x24 : 0x14;
+	csp->scms = cpti->trackinfo.copy ? 0x80 : 0;
+	LBA2MSF(nwa, &csp->min, &csp->sec, &csp->frame);
+	DebugLog("CreateCueSheet: Lead-out.\n", track_num);
+	
+	*cs_ret = cs;
+	*numcs_ret = num_cs;
 	DebugLog("CreateCueSheet: Done.\n", track_num);
 	return RET_OK;
 }
@@ -1740,6 +1737,7 @@ static int CopySession(CMDDRIVE *src, CMDDRIVE *dst, int num_dst,
 	int ret=RET_OK;
 	WORD track_num = *track_num_ret;
 	struct _CUESHEET *cs=NULL, *csp;
+	int num_cs = 0;
 	BOOL done=FALSE;
 	DWORD lba, blocks;
 	DWORD translen, blocksize;
@@ -1756,9 +1754,36 @@ static int CopySession(CMDDRIVE *src, CMDDRIVE *dst, int num_dst,
 		if(ret!=RET_OK)
 			return ret;
 
-		ret = CreateCueSheet(&dst[index], discinfo, track_num, &cs);
+		ret = CreateCueSheet(&dst[index], discinfo, track_num,
+							 &cs, &num_cs, TRUE);
 		if(ret!=RET_OK)
 			return ret;
+
+		if(REALDRIVE(&dst[index])){
+			ret = SendSendCueSheet(&dst[index], cs,
+								   num_cs*sizeof(struct _CUESHEET));
+			if(ret!=RET_OK){
+				MemFree(cs);
+				cs = NULL;
+				if(!(track_num==1 && discinfo->cdtext_size>0)){
+					DispCommandError(&dst[index]);
+					return ret;
+				}
+				/* CD-TEXT𖳌ɂăgC */
+				ret = CreateCueSheet(&dst[index], discinfo, track_num,
+									 &cs, &num_cs, FALSE);
+				if(ret!=RET_OK)
+					return ret;
+				ret = SendSendCueSheet(&dst[index], &cs,
+									   num_cs*sizeof(struct _CUESHEET));
+				if(ret!=RET_OK){
+					MemFree(cs);
+					cs = NULL;
+					DispCommandError(&dst[index]);
+					return ret;
+				}
+			}
+		}
 	}
 
 	for(csp=cs; !done; csp++){
@@ -2139,7 +2164,8 @@ static int ExecCopy(CMDDRIVE *src, CMDDRIVE *dst, int num_dst)
 				/* ŏIgbNBLANKȂ牽I */
 				break;
 			}
-			if(discinfo.trackinfo[track_num-1].tao==FALSE){
+			if((discinfo.trackinfo[track_num-1].tao==FALSE) &&
+			   DT_CD_FAMILY(dst[0].disc_type)){
 				/* SAOL^ */
 				sao = TRUE;
 				ret = CopySession(src, dst, num_dst, &discinfo, &track_num);
@@ -2260,7 +2286,7 @@ void PostProcess(int retcode, CMDDRIVE *src, CMDDRIVE *dstp, int num_dst)
 									UIDMT_QUESTION);
 				if(ret==UIDMRET_OK){
 					for(index=0; index<num_dst; index++){
-						OpenTray(&dstp[index]);
+						OpenTrayImmediate(&dstp[index]);
 					}
 					OpenTray(src);
 				}
