@@ -2,7 +2,7 @@
  * @file netaccess.h
  * @brief lbg[NANZX
  * @author BananaJinn
- * @version $Id: netaccess.h,v 1.9 2006/03/21 15:50:21 bananajinn Exp $
+ * @version $Id: netaccess.h,v 1.11 2007/10/02 15:10:52 bananajinn Exp $
  * ~Օʉ
  * Copyright (C) 2004-2006 BananaJinn<banana@mxh.mesh.ne.jp>.
  */
@@ -17,9 +17,9 @@
 #else
 # include <sys/socket.h>
   typedef int SOCKET;
-# if defined(linux)
-#  include <iconv.h>
-# endif
+#endif
+#if defined(linux) || defined(__MINGW32__)
+# include <iconv.h>
 #endif
 
 #define NETTIMEOUT (60*1000)
@@ -40,7 +40,7 @@ typedef struct {
   } u;
   char *remote_host;
   DWORD error_code;
-#if defined(linux)
+#if defined(linux) || defined(__MINGW32__)
   iconv_t iconv_desc;
 #endif
 } SOCKCB;
@@ -130,13 +130,13 @@ extern int NACreateServer(SOCKCB *scb);
 extern int NAWaitConnect(SOCKCB *scb, DWORD timeout);
 extern int NAConnect(SOCKCB *scb);
 extern int NAClose(SOCKCB *scb);
-extern int NASend(SOCKCB *scb, const char *buffer, int length, DWORD timeout,
+extern int NASend(SOCKCB *scb, const void *buffer, int length, DWORD timeout,
 				  BOOL check_readfd);
-extern int NAReceive(SOCKCB *scb, char *buffer, int length, DWORD timeout);
+extern int NAReceive(SOCKCB *scb, void *buffer, int length, DWORD timeout);
 
-extern int SendNetCmd(SOCKCB *scb, BYTE *cdb, BYTE *buf, DWORD buflen,
+extern int SendNetCmd(SOCKCB *scb, BYTE *cdb, void *buf, DWORD buflen,
 					  BYTE *sensedata, DWORD senselen, int reqflag);
-extern int SendNetCmdLongRead(SOCKCB *scb, BYTE *cdb, BYTE *buf, DWORD buflen,
+extern int SendNetCmdLongRead(SOCKCB *scb, BYTE *cdb, void *buf, DWORD buflen,
 							  BYTE *sensedata, DWORD senselen,
 							  int reqflag, DWORD total_blocks);
 
@@ -150,8 +150,8 @@ extern int NAUIMeter2Initialize(SOCKCB *scb, const char *message);
 extern int NAUIMeter1Update(SOCKCB *scb, float percentage);
 extern int NAUIMeter2Update(SOCKCB *scb, float percentage);
 extern const char *NAGetErrorMessage(SOCKCB *scb);
-#if defined(linux)
-extern char *ConvertCharset(iconv_t iconv_desc, const char *in_string);
+#if defined(linux) || defined(__MINGW32__)
+extern char *ConvertCharcode(iconv_t iconv_desc, const char *in_string);
 #endif
 extern BOOL DispSocketError(SOCKCB *scb, int ret_value);
 
