@@ -2,12 +2,13 @@
  * @file netserver.c
  * @brief T[o
  * @author BananaJinn
- * @version $Id: netserver.c,v 1.6 2006/03/21 14:06:22 bananajinn Exp $
+ * @version $Id: netserver.c,v 1.9 2007/10/02 15:10:52 bananajinn Exp $
  * ~Օʉ
  * Copyright (C) 2004-2006 BananaJinn<banana@mxh.mesh.ne.jp>.
  */
 #include <stdio.h>
 #include <string.h>
+#include <stdlib.h>
 #include <stdarg.h>
 #ifdef linux
 # include <fcntl.h>
@@ -16,9 +17,7 @@
 #if defined(WIN32)
 # include <io.h>
 #endif
-#if !defined(MACOSX)
-# include <malloc.h>
-#endif
+#include "mem.h"
 #include "aspi.h"
 #include "struct.h"
 #include "cmd.h"
@@ -238,7 +237,7 @@ static int DisplayMessage(CMDDRIVE *netdrive, DWORD receive_bytes)
 	  ignore_len = message_len-255;
 	  message_len = 255;
 	}
-	message = (char *)malloc(message_len+1);
+	message = (char *)MemNew(message_len+1);
 	if(message==NULL){
 	  UIDispMessage(MSG_MEM_ALLOC_ERROR
 			/*"mۂɎs܂B"*/, UIDMT_ERROR);
@@ -247,26 +246,26 @@ static int DisplayMessage(CMDDRIVE *netdrive, DWORD receive_bytes)
 	/* bZ[WM */
 	ret = NAReceive(&netdrive->u.net, message, message_len, NETTIMEOUT);
 	if(ret != RET_OK){
-	  free(message);
+	  MemFree(message);
 	  return ret;
 	}
 	ret = NAReceive(&netdrive->u.net, NULL, ignore_len, NETTIMEOUT);
 	if(ret != RET_OK){
-	  free(message);
+	  MemFree(message);
 	  return ret;
 	}
 	message[message_len] = '\0';
-#if defined(linux)
+#if defined(linux) || defined(__MINGW32__)
 	{
-	  char *message_euc = ConvertCharset(netdrive->u.net.iconv_desc,
+	  char *message_euc = ConvertCharcode(netdrive->u.net.iconv_desc,
 										 message);
 	  if(message_euc == NULL){
-	    free(message);
+	    MemFree(message);
 	    UIDispMessage(MSG_CODE_CONV_ERROR
 			  /*"R[hϊɎs܂B"*/, UIDMT_ERROR);
 	    return RET_MEMERR;
 	  }
-	  free(message);
+	  MemFree(message);
 	  message = message_euc;
 	}
 #endif
@@ -288,7 +287,7 @@ static int DisplayMessage(CMDDRIVE *netdrive, DWORD receive_bytes)
 	  UIMeter2Update((float)dispheader.percent);
 	break;
   }
-  free(message);
+  MemFree(message);
   
   return RET_OK;
 }
