@@ -2,7 +2,7 @@
  * @file option.c
  * @brief ʐݒ
  * @author BananaJinn
- * @version $Id: option.c,v 1.21 2007/10/02 15:10:52 bananajinn Exp $
+ * @version $Id: option.c,v 1.22 2008/04/06 15:15:15 bananajinn Exp $
  * ~Օʉ
  * Copyright (C) 2004-2006 BananaJinn<banana@mxh.mesh.ne.jp>.
  */
@@ -406,7 +406,8 @@ int SetOption(CMDDRIVE *reader, CMDDRIVE *writer, int disc_type)
 #endif
   g_Option.flags |= OPFLG_TEMPPATH;
 
-  if(disc_type==DT_DVDPR || disc_type==DT_DVDPRW){
+  if(writer->disc_type==DT_DVDPR || writer->disc_type==DT_DVDPRW ||
+	 writer->disc_type==DT_DVDPRDL || writer->disc_type==DT_DVDPRWDL){
     /* WriteParametersPage ݒ肪̂ */
     g_Option.bufe = TRUE;
     g_Option.test_write = FALSE;
@@ -436,27 +437,30 @@ int SetOption(CMDDRIVE *reader, CMDDRIVE *writer, int disc_type)
   }
 
   if(DT_DVD_FAMILY(disc_type)){
-    g_Option.flags |= OPFLG_DVD;
-    g_Option.dao = TRUE;
-    g_Option.flags |= OPFLG_DAO;
+	  g_Option.flags |= OPFLG_DVD;
+	  if(writer->disc_type!=DT_DVDPR && writer->disc_type!=DT_DVDPRW &&
+		 writer->disc_type!=DT_DVDPRDL && writer->disc_type!=DT_DVDPRWDL){
+		  g_Option.dao = TRUE;
+		  g_Option.flags |= OPFLG_DAO;
+	  }
   }
 
   if(reader!=NULL && writer!=NULL){
-    if(reader->type==CMDDRVTYPE_DRIVE && writer->type==CMDDRVTYPE_DRIVE){
-      if(reader->u.drive.hid != writer->u.drive.hid ||
-	 reader->u.drive.tid != writer->u.drive.tid){
-	g_Option.on_the_fly = TRUE;
-	g_Option.flags |= OPFLG_ONTHEFLY;
-      }
-    }
-    else{
-      g_Option.on_the_fly = TRUE;
-      g_Option.flags |= OPFLG_ONTHEFLY;
-      g_Option.flags &= ~OPFLG_DAO;
-    }
+	  if(reader->type==CMDDRVTYPE_DRIVE && writer->type==CMDDRVTYPE_DRIVE){
+		  if(reader->u.drive.hid != writer->u.drive.hid ||
+			 reader->u.drive.tid != writer->u.drive.tid){
+			  g_Option.on_the_fly = TRUE;
+			  g_Option.flags |= OPFLG_ONTHEFLY;
+		  }
+	  }
+	  else{
+		  g_Option.on_the_fly = TRUE;
+		  g_Option.flags |= OPFLG_ONTHEFLY;
+		  g_Option.flags &= ~OPFLG_DAO;
+	  }
   }
   else{
-    g_Option.on_the_fly = TRUE;
+	  g_Option.on_the_fly = TRUE;
   }
 
   ret = GetReadableSpeed(reader, &g_Option);
