@@ -2,7 +2,7 @@
  * @file option.h
  * @brief ʐݒ
  * @author BananaJinn
- * @version $Id: option.h,v 1.10 2006/06/30 15:19:12 bananajinn Exp $
+ * @version $Id: option.h,v 1.12 2006/09/13 22:34:55 bananajinn Exp $
  * ~Օʉ
  * Copyright (C) 2004-2006 BananaJinn<banana@mxh.mesh.ne.jp>.
  */
@@ -25,6 +25,7 @@ typedef struct {
   int num_writable_speed;
   WORD flags;		/* Lȍڂ */
   char temppath[_MAX_PATH];
+  BOOL outside;
 } OPTIONS;
 
 /* flags value */
@@ -34,6 +35,7 @@ typedef struct {
 #define OPFLG_DAO	(1<<3)
 #define OPFLG_TEMPPATH	(1<<4)
 #define OPFLG_DVD	(1<<5)	// DVDnǂ
+#define OPFLG_OUTSIDE	(1<<6)
 
 #ifdef __cplusplus
 extern "C" {
