@@ -2,7 +2,7 @@
  * @file scan.c
  * @brief u
  * @author BananaJinn
- * @version $Id: scan.c,v 1.11 2006/06/01 16:50:51 bananajinn Exp $
+ * @version $Id: scan.c,v 1.13 2007/10/02 15:10:52 bananajinn Exp $
  * ~Օʉ
  * Copyright (C) 2004-2006 BananaJinn<banana@mxh.mesh.ne.jp>.
  */
@@ -10,6 +10,7 @@
 #include <string.h>
 #include <stdlib.h>
 
+#include "mem.h"
 #include "aspi.h"
 #include "cmd.h"
 #include "scan.h"
@@ -51,7 +52,7 @@ SCAN_t *ScanDrive(BOOL bWriter)
 	SCAN_t *drives;
 	CMDDRIVE drive;
 
-	drives = (SCAN_t *)malloc(sizeof(SCAN_t)*MAX_SCAN);
+	drives = (SCAN_t *)MemNew(sizeof(SCAN_t)*MAX_SCAN);
 
 #if defined(WIN32) || defined(linux)
 	max_hid = GetHostAdapterCount();
@@ -115,10 +116,10 @@ SCAN_t *ScanDrive(BOOL bWriter)
 				sprintf(drives[num_drive].inqdata, "[%c:] ", tid+'C');
 			else
 #endif
-			sprintf(drives[num_drive].inqdata, "[%d:%d] ", hid, tid);
-			drives[num_drive].inqdata[strlen(drives[num_drive].inqdata)+40]='\0';
-			strncpy(drives[num_drive].inqdata+strlen(drives[num_drive].inqdata),
-					drive.data_buf+8, 40);
+			sprintf((char *)drives[num_drive].inqdata, "[%d:%d] ", hid, tid);
+			drives[num_drive].inqdata[strlen((char *)drives[num_drive].inqdata)+40]='\0';
+			strncpy((char *)drives[num_drive].inqdata+strlen((char *)drives[num_drive].inqdata),
+					(char *)drive.data_buf+8, 40);
 #endif
 			drives[num_drive].hid = hid;
 			drives[num_drive].tid = tid;
