@@ -90,10 +90,12 @@ struct _MODEPAGE05 {				/* Write Parameters */
 	BYTE	res_9;					/* Reserved			     */
 	BYTE	packet_size[4];			/* # of user datablocks/fixed packet */
 	BYTE	audio_pause_len[2];		/* # of blocks where index is zero   */
-	BYTE	mc_val;					/* MCN valid */
+	BYTE	res_16          : 7;	/* Reserved              */
+	BYTE	mc_val          : 1;	/* MCN valid */
 	BYTE	media_cat_number[13];	/* Media catalog Number (MCN)	     */
 	BYTE	res_30_31[2];
-	BYTE	tc_val;					/* ISRC valid */
+	BYTE	res_32          : 7;	/* Reserved              */
+	BYTE	tc_val          : 1;	/* ISRC valid */
 	BYTE	ISRC[12];				/* ISRC for this track		     */
 	BYTE	res_45_47;
 	BYTE	sub_header[4];
@@ -119,10 +121,12 @@ struct _MODEPAGE05 {				/* Write Parameters */
 	BYTE	res_9;					/* Reserved			     */
 	BYTE	packet_size[4];			/* # of user datablocks/fixed packet */
 	BYTE	audio_pause_len[2];		/* # of blocks where index is zero   */
-	BYTE	mc_val;					/* MCN valid */
+	BYTE	mc_val          : 1;	/* MCN valid */
+	BYTE	res_16          : 7;	/* Reserved              */
 	BYTE	media_cat_number[13];	/* Media catalog Number (MCN)	     */
 	BYTE	res_30_31[2];
-	BYTE	tc_val;					/* ISRC valid */
+	BYTE	tc_val          : 1;	/* ISRC valid */
+	BYTE	res_32          : 7;	/* Reserved              */
 	BYTE	ISRC[12];				/* ISRC for this track		     */
 	BYTE	res_45_47;
 	BYTE	sub_header[4];
@@ -642,19 +646,31 @@ struct _CUESHEET {
 #define DT_UNKNOWN	0x0000	/* mfBXN */
 #define DT_CDROM	0x0008	/* CD-ROM */
 #define DT_CDR		0x0009	/* CD-R */
-#define DT_CDRW		0x000a	/* CD-RW */
+#define DT_CDRW		0x000A	/* CD-RW */
 #define DT_DVDROM	0x0010	/* DVD-ROM */
 #define DT_DVDR		0x0011	/* DVD-R */
 #define DT_DVDRAM	0x0012	/* DVD-RAM */
 #define DT_DVDRWO	0x0013	/* DVD-RW(tH[}bg) */
 #define DT_DVDRWS	0x0014	/* DVD-RW(V[PVL^) */
+#define DT_DVDRDL	0x0015	/* DVD-R Dual Layer(V[PVL^) */
+#define DT_DVDRDLJ	0x0016	/* DVD-R Dual Layer(C[WvL^) */
+#define DT_DVDRWDL	0x0017	/* DVD-RW Dual Layer */
 #define DT_DVDPRW	0x001A	/* DVD+RW */
 #define DT_DVDPR	0x001B	/* DVD+R */
+#define DT_DVDPRWDL	0x002A	/* DVD+RW Dual Layer */
+#define DT_DVDPRDL	0x002B	/* DVD+R Dual Layer */
+#define DT_BDROM	0x0040	/* BD-ROM */
+#define DT_BDR		0x0041	/* BD-R(V[PVL^) */
+#define DT_BDRR		0x0042	/* BD-R(_L^) */
+#define DT_BDRE		0x0043	/* BD-RE */
 
 #define DT_CD_FAMILY(d)		(d==DT_CDROM||d==DT_CDR||d==DT_CDRW)
 #define DT_DVD_FAMILY(d)	(d>=DT_DVDROM)
 #define DT_WRITABLE(d)		\
 	(d==DT_CDR||d==DT_CDRW||\
-	d==DT_DVDR||d==DT_DVDRWO||d==DT_DVDRWS||d==DT_DVDPRW||d==DT_DVDPR)
+	d==DT_DVDR||d==DT_DVDRWO||d==DT_DVDRWS||\
+	d==DT_DVDRDL||d==DT_DVDRDLJ||d==DT_DVDRWDL||\
+	d==DT_DVDPRW||d==DT_DVDPR||\
+	d==DT_DVDPRWDL||d==DT_DVDPRDL)
 
 #endif /* !__STRUCT_H__ */
