@@ -23,7 +23,7 @@ make clean
 rm -rf $TMPDIR
 mkdir $TMPDIR
 cp -pr ../../$PROG $TMPDIR/$PROGDIR
-find $TMPDIR/$PROG"-"$VERNUM -type d -name CVS -exec rm -rf {} \; \
+find $TMPDIR/$PROG"-"$VERNUM \( -name CVS -o -name '*~' \) -exec rm -rf {} \; \
 	> /dev/null 2>&1
 pushd $TMPDIR > /dev/null
 tar zcf $SOURCEFILE $PROGDIR
