@@ -50,7 +50,7 @@ void FreeDrive(DRIVE *drive)
 int SetAspiSetting(DRIVE *drive, int *ha, int *tg, DWORD *timeout)
 {
   BOOL target_changed=FALSE;
-  char devname[12];
+  char *devname = NULL;
 
   if(ha!=NULL)
     if(*ha>=3)
@@ -75,11 +75,14 @@ int SetAspiSetting(DRIVE *drive, int *ha, int *tg, DWORD *timeout)
     if(drive->fd>=0){
       close(drive->fd);
     }
-    if(drive->hid==0)
-      sprintf(devname, "/dev/hd%c", drive->tid+'a');
-    else
-      sprintf(devname, "/dev/scd%c", drive->tid+'0');
+	
+	devname = GetDeviceNameByID(drive->hid, drive->tid);
+#if defined(K24)
     drive->fd = open(devname, O_RDONLY|O_NONBLOCK);
+#else
+    drive->fd = open(devname, O_RDWR|O_NONBLOCK);
+#endif
+	free(devname);
     if(drive->fd<0){
       return RET_NG;
     }
@@ -188,3 +191,56 @@ int GetMaxTarget()
 {
   return 26;
 }
+
+
+/**
+ * @brief ǥХե̾IDֹ
+ * @param[in] devfile ǥХե̾(/dev/xxx ޤ xxx)
+ * @param[out] ha ۥȥץID(/dev/hd?ξ0/dev/scd?ξ1)
+ * @param[out] tg åID(/dev/hdaƬȤֹޤ/dev/scd0ƬȤֹ)
+ * @retval RET_OK Ѵ
+ * @retval RET_NG Ѵ(ʥǥХ̾ʤ)
+ */
+int GetDeviceIDByName(const char *devfile, int *ha, int *tg)
+{
+	if((ha == NULL) || (tg == NULL)){
+		return RET_NG;
+	}
+	if(!strncmp(devfile, "/dev/", 5)){
+		devfile += 5;
+	}
+	if(!strncmp(devfile, "hd", 2)){
+		*ha = 0;
+		*tg = devfile[2]-'a';
+	}
+	else if(!strncmp(devfile, "scd", 3)){
+		*ha = 1;
+		*tg = devfile[3]-'0';
+	}
+	else{
+		return RET_NG;
+	}
+	return RET_OK;
+}
+
+/**
+ * @brief IDֹ椫ǥХե̾
+ * @param[in] ha ۥȥץID(/dev/hd?ξ0/dev/scd?ξ1)
+ * @param[in] tg åID(/dev/hdaƬȤֹޤ/dev/scd0ƬȤֹ)
+ * @return ѴϥǥХե̾򡢥顼NULL֤֤줿Хåե free
+ *         ǥɬס
+ */
+char *GetDeviceNameByID(int ha, int tg)
+{
+	char *buf = NULL;
+
+	if(ha == 0){
+		buf = malloc(8+1);
+		snprintf(buf, 8+1, "/dev/hd%c", tg+'a');
+	}
+	else{
+		buf = malloc(9+1);
+		snprintf(buf, 9+1, "/dev/scd%c", tg+'0');
+	}
+	return buf;
+}
