@@ -23,6 +23,7 @@ extern int SendAspiCmd(DRIVE *drive, BYTE *cdb, BYTE *buf, DWORD buflen,
 		       BYTE *sensedata, DWORD senselen, BYTE reqflag);
 extern int GetHostAdapterCount(void);
 extern int GetMaxTarget(void);
-
+extern int GetDeviceIDByName(const char *devfile, int *ha, int *tg);
+extern char *GetDeviceNameByID(int ha, int tg);
 
 #endif /* !__ASPI_H__ */
