@@ -1,5 +1,6 @@
-/* ʣ̲
- * Copyright (C) 2004 Kagetani Hideto
+/**
+ * ʣ̲
+ * Copyright (C) 2004-2008 Kagetani Hideto
  */
 
 #include <stdio.h>
@@ -146,7 +147,21 @@ int UISetting(OPTIONS *option)
 int UIFileDialog(BOOL bOpen, char *filename, int size, const char *suffix)
 {
   int ret;
+  const char *arg = NULL;
+  extern const char *GetArgReader();
+  extern const char *GetArgWriter();
 
+  /* ޥɥ饤Ǥλǧ */
+  arg = bOpen ? GetArgReader() : GetArgWriter();
+  if(arg != NULL){
+	  if(strlen(arg) > 0){
+		  /* ꤵƤФե̾Ȥ֤ */
+		  strncpy(filename, arg, size);
+		  filename[size-1] = '\0';
+		  return UIDMRET_OK;
+	  }
+  }
+  
   ret=FileDialog(bOpen, filename, size, suffix);
   return ret==FDR_OK ? UIDMRET_OK : UIDMRET_CANCEL;
 }
