@@ -20,11 +20,13 @@
 	[checkBUFE setState : (option->bufe ? NSOnState:NSOffState)];
 	[checkOnTheFly setState : (option->on_the_fly ? NSOnState:NSOffState)];
 	[checkDiscAtOnce setState : (option->dao ? NSOnState:NSOffState)];
+	[checkOutSide setState : (option->outside ? NSOnState:NSOffState)];
 	
 	[checkTestWrite setEnabled : ((option->flags & OPFLG_TESTWRITE) ? YES:NO)];
 	[checkBUFE setEnabled : ((option->flags & OPFLG_BUFE) ? YES:NO)];
 	[checkOnTheFly setEnabled : ((option->flags & OPFLG_ONTHEFLY) ? YES:NO)];
 	[checkDiscAtOnce setEnabled : ((option->flags & OPFLG_DAO) ? YES:NO)];
+	[checkOutSide setEnabled : ((option->flags & OPFLG_OUTSIDE) ? YES:NO)];
 	
 	[textTempDirectory setStringValue :
 		[NSString stringWithCString : option->temppath]];
@@ -50,6 +52,7 @@
 	option->bufe = [checkBUFE state]==NSOnState;
 	option->on_the_fly = [checkOnTheFly state]==NSOnState;
 	option->dao = [checkDiscAtOnce state]==NSOnState;
+	option->outside = [checkOutSide state]==NSOnState;
 	
 	option->read_speed = atoi([[readSpeedSel titleOfSelectedItem] cString]);
 	option->write_speed = atoi([[writeSpeedSel titleOfSelectedItem] cString]);
