@@ -520,14 +520,55 @@ LRESULT CEnbanFukusyaDlg::OnKickIdle(WPARAM wParam, LPARAM lParam)
 	m_CmbWriter.AddString("lbg[N");
 	m_nWriteDriveNet = m_CmbWriter.GetCount()-1;
 
+	/*
+	 * R}hCɂǎ摕uwmF
+	 */
+#define IS_DEVICE_ISO(s) \
+		((strlen(s) > 4) && (stricmp(s+strlen(s)-4, ".iso")==0))
+#define IS_DEVICE_EMG(s) \
+		((strlen(s) > 4) && (stricmp(s+strlen(s)-4, ".emg")==0))
+	CString csTmp;
+	LPCTSTR lpszTmp;
+	lpszTmp = GetArgReader();
+	if(lpszTmp != NULL){
+		if(IS_DEVICE_ISO(lpszTmp)){
+			csTmp.Format("ISO(%s)", lpszTmp);
+			m_CmbReader.DeleteString(m_nReadDriveISO);
+			m_CmbReader.InsertString(m_nReadDriveISO, csTmp);
+			m_CmbReader.SetCurSel(m_nReadDriveISO);
+			m_CmbReader.EnableWindow(FALSE);
+		}
+		else if(IS_DEVICE_EMG(lpszTmp)){
+			csTmp.Format("~ՃC[W(%s)", lpszTmp);
+			m_CmbReader.DeleteString(m_nReadDriveEmg);
+			m_CmbReader.InsertString(m_nReadDriveEmg, csTmp);
+			m_CmbReader.SetCurSel(m_nReadDriveEmg);
+			m_CmbReader.EnableWindow(FALSE);
+		}
+	}
+	/*
+	 * R}hCɂ鏑uwmF
+	 */
+	lpszTmp = GetArgWriter();
+	if(lpszTmp != NULL){
+		if(IS_DEVICE_ISO(lpszTmp)){
+			csTmp.Format("ISO(%s)", lpszTmp);
+			m_CmbWriter.DeleteString(m_nWriteDriveISO);
+			m_CmbWriter.InsertString(m_nWriteDriveISO, csTmp);
+			m_CmbWriter.SetCurSel(m_nWriteDriveISO);
+			m_CmbWriter.EnableWindow(FALSE);
+		}
+		else if(IS_DEVICE_EMG(lpszTmp)){
+			csTmp.Format("~ՃC[W(%s)", lpszTmp);
+			m_CmbWriter.DeleteString(m_nWriteDriveEmg);
+			m_CmbWriter.InsertString(m_nWriteDriveEmg, csTmp);
+			m_CmbWriter.SetCurSel(m_nWriteDriveEmg);
+			m_CmbWriter.EnableWindow(FALSE);
+		}
+	}
+
 	m_bScanDone = TRUE;
-//	{
-//		MsgDlg.Disp("Q MB_YESNOCANCEL ̃eXg", NULL, MB_YESNOCANCEL|MB_ICONEXCLAMATION);
-//		MsgDlg.Disp("H MB_OK ̃eXg", NULL, MB_OK|MB_ICONQUESTION);
-//		MsgDlg.Disp("G[ MB_OKCANCEL ̃eXg", NULL, MB_OKCANCEL|MB_ICONSTOP);
-//		MsgDlg.Disp("ʂ MB_ABORTRETRYIGNORE ̃eXg", NULL, MB_ABORTRETRYIGNORE);
-//		MsgDlg.Disp("sbZ[W\ñeXg", "Ȃ");
-//	}
+
 	return 0;
 }
 
@@ -579,7 +620,7 @@ void CEnbanFukusyaDlg::OnOK()
 	int ret;
 	DRIVEID reader, *writerp=NULL;
 	int sel_reader, sel_writer;
-	BOOL bOneDrive = FALSE;
+	//BOOL bOneDrive = FALSE;
 	int nWriter;
 	int nIndex;
 
@@ -736,6 +777,10 @@ LRESULT CEnbanFukusyaDlg::OnUICtl(WPARAM wParam, LPARAM lParam)
 		break;
 	case UICTL_SETTING:
 		return Setting((OPTIONS *)lParam);
+	case UICTL_GETARGREADER:
+		return (LONG)GetArgReader();
+	case UICTL_GETARGWRITER:
+		return (LONG)GetArgWriter();
 	}
 
 	return 0;
@@ -856,3 +901,25 @@ void CEnbanFukusyaDlg::SaveIniFile()
 	}
 	WriteRegString("theme", type);
 }
+
+void CEnbanFukusyaDlg::SetArgReader(LPCTSTR lpszReader)
+{
+	m_csArgReader = lpszReader;
+}
+
+LPCTSTR CEnbanFukusyaDlg::GetArgReader()
+{
+	return m_csArgReader;
+}
+
+void CEnbanFukusyaDlg::SetArgWriter(LPCTSTR lpszWriter)
+{
+	m_csArgWriter = lpszWriter;
+}
+
+
+LPCTSTR CEnbanFukusyaDlg::GetArgWriter()
+{
+	return m_csArgWriter;
+}
+
