@@ -53,6 +53,12 @@ public:
 	virtual void DoDataExchange(CDataExchange* pDX);	// DDX/DDV ̃T|[g
 	//}}AFX_VIRTUAL
 
+public:
+	void SetArgReader(LPCTSTR lpszReader);
+	LPCTSTR GetArgReader();
+	void SetArgWriter(LPCTSTR lpszWriter);
+	LPCTSTR GetArgWriter();
+
 // Cve[V
 protected:
 	HICON m_hIcon;
@@ -96,6 +102,8 @@ private:
 	int m_nWriteDriveEmg;
 	int m_nReadDriveNet;
 	int m_nWriteDriveNet;
+	CString m_csArgReader;
+	CString m_csArgWriter;
 };
 
 //{{AFX_INSERT_LOCATION}}
