@@ -33,6 +33,7 @@ void CSettingDlg::DoDataExchange(CDataExchange* pDX)
 {
 	CDialog::DoDataExchange(pDX);
 	//{{AFX_DATA_MAP(CSettingDlg)
+	DDX_Control(pDX, IDC_CHK_OUTSIDE, m_ChkOutside);
 	DDX_Control(pDX, IDC_STC_TEMPPATH, m_StcTempPath);
 	DDX_Control(pDX, IDC_EDT_TEMPPATH, m_EdtTempPath);
 	DDX_Control(pDX, IDOK, m_BtnOK);
@@ -73,6 +74,7 @@ BOOL CSettingDlg::OnInitDialog()
 	m_ChkTestWrite.SetTheme(pTheme);
 	m_ChkDAO.SetTheme(pTheme);
 	m_ChkOnthefly.SetTheme(pTheme);
+	m_ChkOutside.SetTheme(pTheme);
 	m_StcTempPath.SetTheme(pTheme);
 
 	if(m_pOption==NULL){
@@ -85,11 +87,13 @@ BOOL CSettingDlg::OnInitDialog()
 	m_ChkTestWrite.SetCheckState(m_pOption->test_write);
 	m_ChkOnthefly.SetCheckState(m_pOption->on_the_fly);
 	m_ChkDAO.SetCheckState(m_pOption->dao);
+	m_ChkOutside.SetCheckState(m_pOption->outside);
 	// L/ݒ
 	m_ChkBUFE.EnableWindow((m_pOption->flags & OPFLG_BUFE)!=0);
 	m_ChkTestWrite.EnableWindow((m_pOption->flags & OPFLG_TESTWRITE)!=0);
 	m_ChkOnthefly.EnableWindow((m_pOption->flags & OPFLG_ONTHEFLY)!=0);
 	m_ChkDAO.EnableWindow((m_pOption->flags & OPFLG_DAO)!=0);
+	m_ChkOutside.EnableWindow((m_pOption->flags & OPFLG_OUTSIDE)!=0);
 	// xݒ荀ڂݒ
 	SetSpeedItems(&m_CmbReadSpeed, m_pOption->read_speed,
 			(m_pOption->flags & OPFLG_DVD)!=0,
@@ -138,6 +142,8 @@ void CSettingDlg::OnOK()
 		m_pOption->on_the_fly = m_ChkOnthefly.GetCheckState();
 	if((m_pOption->flags & OPFLG_DAO)!=0)
 		m_pOption->dao = m_ChkDAO.GetCheckState();
+	if((m_pOption->flags & OPFLG_OUTSIDE)!=0)
+		m_pOption->outside = m_ChkOutside.GetCheckState();
 
 	CString csSpeed;
 	int sel;
