@@ -110,7 +110,7 @@
 #define IDS_NETWORK_ERROR_              221
 #define IDS_ABORTED                     222
 #define IDS_COMPLETE_SUCCESS            223
-#define IDS_ERROR_OCCURRED              224
+#define IDS_ERROR_OCCURRED_CMDLOG       224
 #define IDS_MEM_ALLOC_ERROR             225
 #define IDS_CANT_COPY_DIFFERENT_TYPE    226
 #define IDS_CANT_OPEN_IMAGE             227
@@ -120,6 +120,9 @@
 #define IDS_UNKNOWN_COMMAND             231
 #define IDS_INVALID_IMAGE_FILE          232
 #define IDS_COMPLETE_SUCCESS_AND_EJECT  233
+#define IDS_TOTAL_REMAINS_              234
+#define IDS_ERROR_OCCURRED_CMDLOG2      235
+#define IDS_ERROR_OCCURRED              235
 #define IDC_COMBO1                      1000
 #define IDC_COMBO2                      1001
 #define IDC_PROGRESS1                   1002
@@ -146,6 +149,7 @@
 #define IDC_STC_TEMPPATH                1024
 #define IDC_EDT_TEMPPATH                1025
 #define IDC_STC_INFO                    1026
+#define IDC_CHK_OUTSIDE                 1026
 #define IDC_EDT_ADDRESS                 1027
 #define IDC_EDT_PORT                    1028
 #define IDC_STC_ADDRESS                 1029
