@@ -102,6 +102,26 @@ int UISetting(OPTIONS *option)
 
 int UIFileDialog(BOOL bOpen, char *filename, int size, const char *suffix)
 {
+	LPCTSTR lpszArg = NULL;
+
+	/*
+	 * R}hCł̎wmF
+	 */
+	if(bOpen){
+		lpszArg = (LPCTSTR)::SendMessage(g_hWnd, WM_USER_UICTL, UICTL_GETARGREADER, 0);
+	}
+	else{
+		lpszArg = (LPCTSTR)::SendMessage(g_hWnd, WM_USER_UICTL, UICTL_GETARGWRITER, 0);
+	}
+	if(lpszArg != NULL){
+		if(strlen(lpszArg) > 0){
+			/* w肳Ă΂t@CƂĕԂ */
+			strncpy(filename, lpszArg, size);
+			filename[size-1] = '\0';
+			return UIDMRET_OK;
+		}
+	}
+
 	CString csFilter;
 	if(suffix != NULL){
 		csFilter.Format("%s files (*.%s)|*.%s|All Files (*.*)|*.*||", suffix, suffix, suffix);
