@@ -18,6 +18,8 @@ extern "C" {
 #define UICTL_METER2SETPOS	3
 #define UICTL_SETTING		4
 #define UICTL_DISPINFO		5
+#define UICTL_GETARGREADER	6
+#define UICTL_GETARGWRITER	7
 
 void UISetHWND(HWND hWnd);
 BOOL UICheckAbort();
